@@ -28,6 +28,8 @@
 #include "bjb-main-view.h"
 #include "bjb-organize-dialog.h"
 #include "bjb-selection-toolbar.h"
+#include "bjb-share.h"
+#include "bjb-trash-bar.h"
 #include "bjb-window-base.h"
 
 enum
@@ -40,20 +42,26 @@ enum
 
 static GParamSpec *properties[NUM_PROPERTIES] = { NULL, };
 
+
+/* Selection toolbar
+ * it uses two widgets
+ * header bar for classic view -> only show when selection
+ * toolbar for archive view -> always show bar for trash bin
+ */
+
 struct _BjbSelectionToolbarPrivate
 {
   GtkHeaderBar       *bar;
-
-  GtkWidget          *toolbar_trash;
-  GtkWidget          *toolbar_color;
-  GtkWidget          *toolbar_tag;
-
-  /* sure */
   BjbMainView        *view ;
+  BjbTrashBar        *trash_bar;
   GtkWidget          *widget ;
   GdMainView         *selection ;
 
-  /* misc gtk */
+  /* Header bar members. Classic view */
+  GtkWidget          *toolbar_trash;
+  GtkWidget          *toolbar_color;
+  GtkWidget          *toolbar_tag;
+  GtkWidget          *toolbar_share;
   GtkToolItem        *left_group;
   GtkToolItem        *right_group;
   GtkToolItem        *separator;
@@ -131,6 +139,22 @@ action_delete_selected_items (GtkWidget *w, BjbSelectionToolbar *self)
 }
 
 
+static void
+action_share_item_callback (GtkWidget *w, BjbSelectionToolbar *self)
+{
+  GList *l, *selection;
+
+  selection = bjb_main_view_get_selected_items (self->priv->view);
+
+  for (l=selection; l!= NULL; l=l->next)
+  {
+     on_email_note_callback (w, l->data);
+  }
+
+  g_list_free (selection);
+}
+
+
 static void
 bjb_selection_toolbar_fade_in (BjbSelectionToolbar *self)
 {
@@ -151,6 +175,7 @@ bjb_selection_toolbar_set_item_visibility (BjbSelectionToolbar *self)
   BjbSelectionToolbarPrivate *priv;
   GList *l, *selection;
   GdkRGBA color;
+  gboolean can_tag, can_color, can_share;
 
   g_return_if_fail (BJB_IS_SELECTION_TOOLBAR (self));
 
@@ -158,41 +183,44 @@ bjb_selection_toolbar_set_item_visibility (BjbSelectionToolbar *self)
   selection = bjb_main_view_get_selected_items (priv->view);
 
 
-  /* Color */
-  gtk_widget_set_sensitive (priv->toolbar_color, FALSE);
+  /* Default */
+  can_color = TRUE;
+  can_tag = TRUE;
+  can_share = TRUE;
 
 
+  /* Adapt */
   for (l=selection; l !=NULL; l=l->next)
   {
-    if (!biji_item_has_color (l->data))
+    if (can_tag == TRUE) /* tag is default. check if still applies */
     {
-      gtk_widget_set_sensitive (priv->toolbar_color, FALSE);
-      break;
+      if (!biji_item_is_collectable (l->data))
+        can_tag = FALSE;
     }
 
-    else if (BIJI_IS_NOTE_OBJ (l->data))
+
+    if (can_color == TRUE) /* color is default. check */
     {
-      if (biji_note_obj_get_rgba (BIJI_NOTE_OBJ (l->data), &color))
-      {
-        gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (priv->toolbar_color), &color);
-        gtk_widget_set_sensitive (priv->toolbar_color, TRUE);
-        break;
-      }
+      if (!BIJI_IS_NOTE_OBJ (l->data)
+          || !biji_item_has_color (l->data)
+          || !biji_note_obj_get_rgba (BIJI_NOTE_OBJ (l->data), &color))
+        can_color = FALSE;
+
+     else
+       gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (priv->toolbar_color), &color);
+    }
+
+    if (can_share == TRUE) /* share is default. check. */
+    {
+      if (!BIJI_IS_NOTE_OBJ (l->data))
+        can_share = FALSE;
     }
   }
 
 
-  /* Organize */
-  gtk_widget_set_sensitive (priv->toolbar_tag, TRUE);
-
-  for (l=selection; l!=NULL; l=l->next)
-  {
-    if (!biji_item_is_collectable (l->data))
-    {
-      gtk_widget_set_sensitive (priv->toolbar_tag, FALSE);
-      break;
-    }
-  }
+  gtk_widget_set_sensitive (priv->toolbar_color, can_color);
+  gtk_widget_set_sensitive (priv->toolbar_tag, can_tag);
+  gtk_widget_set_sensitive (priv->toolbar_share, can_share);
 
   g_list_free (selection);
 }
@@ -200,10 +228,35 @@ bjb_selection_toolbar_set_item_visibility (BjbSelectionToolbar *self)
 static void
 bjb_selection_toolbar_selection_changed (GdMainView *view, gpointer user_data)
 {
-  
-  BjbSelectionToolbar *self = BJB_SELECTION_TOOLBAR (user_data);
-  GList *selection;
 
+  BjbSelectionToolbar *self;
+  BjbSelectionToolbarPrivate *priv;
+  GList *selection;
+  BijiItemsGroup group;
+
+  self = BJB_SELECTION_TOOLBAR (user_data);
+  priv = self->priv;
+  group = bjb_controller_get_group (
+            bjb_window_base_get_controller (
+              BJB_WINDOW_BASE (
+                bjb_main_view_get_window (self->priv->view))));
+
+
+  /* always show bar for archive view */
+  if (group  == BIJI_ARCHIVED_ITEMS)
+  {
+    priv->bar = g_object_ref (priv->bar);
+    bjb_selection_toolbar_fade_in (self);
+    gtk_container_remove (GTK_CONTAINER (self), GTK_WIDGET (priv->bar));
+    gtk_container_add (GTK_CONTAINER (self), GTK_WIDGET (priv->trash_bar));
+    bjb_trash_bar_set_visibility (priv->trash_bar);
+    return;
+  }
+
+
+  priv->trash_bar = g_object_ref (priv->trash_bar);
+  gtk_container_remove (GTK_CONTAINER (self), GTK_WIDGET (priv->trash_bar));
+  gtk_container_add (GTK_CONTAINER (self), GTK_WIDGET (priv->bar));
   selection = gd_main_view_get_selection(view);
 
   if (g_list_length (selection) > 0)
@@ -211,7 +264,7 @@ bjb_selection_toolbar_selection_changed (GdMainView *view, gpointer user_data)
     bjb_selection_toolbar_set_item_visibility (self);
     bjb_selection_toolbar_fade_in (self);
   }
-  
+
   else
     bjb_selection_toolbar_fade_out (self);
 }
@@ -227,8 +280,8 @@ static void
 bjb_selection_toolbar_init (BjbSelectionToolbar *self)
 {
   BjbSelectionToolbarPrivate *priv;
-  GtkWidget                  *widget;
-  
+  GtkWidget                  *widget, *share;
+  GtkSizeGroup *size;
 
   self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, BJB_TYPE_SELECTION_TOOLBAR, BjbSelectionToolbarPrivate);
   priv = self->priv;
@@ -240,10 +293,12 @@ bjb_selection_toolbar_init (BjbSelectionToolbar *self)
   priv->bar = GTK_HEADER_BAR (gtk_header_bar_new ());
   gtk_container_add (GTK_CONTAINER (self), GTK_WIDGET (priv->bar));
 
-  /* Trash notes */
-  priv->toolbar_trash = gtk_button_new_with_label (_("Delete"));
-  gtk_widget_set_valign (priv->toolbar_trash, GTK_ALIGN_CENTER);
-  gtk_header_bar_pack_start (priv->bar, priv->toolbar_trash);
+
+  /* Notes tags */
+  priv->toolbar_tag = gtk_button_new_with_label (_("Notebooks"));
+  gtk_widget_set_valign (priv->toolbar_tag, GTK_ALIGN_CENTER);
+  gtk_header_bar_pack_start (priv->bar, priv->toolbar_tag);
+
 
 
   /* Notes color */
@@ -251,13 +306,35 @@ bjb_selection_toolbar_init (BjbSelectionToolbar *self)
   gtk_widget_set_tooltip_text (GTK_WIDGET (priv->toolbar_color),
                                _("Note color"));
   gtk_widget_set_valign (priv->toolbar_color, GTK_ALIGN_CENTER);
-  gtk_header_bar_pack_end (priv->bar, priv->toolbar_color);
+  gtk_header_bar_pack_start (priv->bar, priv->toolbar_color);
 
 
-  /* Notes tags */
-  priv->toolbar_tag = gtk_button_new_with_label (_("Notebooks"));
-  gtk_widget_set_valign (priv->toolbar_tag, GTK_ALIGN_CENTER);
-  gtk_header_bar_pack_end (priv->bar, priv->toolbar_tag);
+  /* Share */
+  priv->toolbar_share = gtk_button_new ();
+  share = gtk_image_new_from_icon_name ("send-to-symbolic", GTK_ICON_SIZE_MENU);
+  gtk_button_set_image (GTK_BUTTON (priv->toolbar_share), share);
+  gtk_widget_set_valign (share, GTK_ALIGN_CENTER);
+  gtk_style_context_add_class (gtk_widget_get_style_context (priv->toolbar_share),
+                               "image-button");
+  gtk_widget_set_tooltip_text (priv->toolbar_share, _("Share note"));
+  gtk_header_bar_pack_start (priv->bar, priv->toolbar_share);
+
+
+  /* Trash notes */
+  priv->toolbar_trash = gtk_button_new_with_label (_("Move to Trash"));
+  gtk_widget_set_valign (priv->toolbar_trash, GTK_ALIGN_CENTER);
+  gtk_header_bar_pack_end (priv->bar, priv->toolbar_trash);
+
+
+
+  /* Align buttons */
+  size = gtk_size_group_new (GTK_SIZE_GROUP_VERTICAL);
+  gtk_size_group_add_widget (GTK_SIZE_GROUP (size), priv->toolbar_tag);
+  gtk_size_group_add_widget (GTK_SIZE_GROUP (size), priv->toolbar_color);
+  gtk_size_group_add_widget (GTK_SIZE_GROUP (size), priv->toolbar_share);
+  gtk_size_group_add_widget (GTK_SIZE_GROUP (size), priv->toolbar_trash);
+  g_object_unref (size);
+
 
 
   gtk_widget_show_all (widget);
@@ -310,23 +387,35 @@ bjb_selection_toolbar_constructed(GObject *obj)
 {
   BjbSelectionToolbar *self = BJB_SELECTION_TOOLBAR(obj);
   BjbSelectionToolbarPrivate *priv = self->priv ;
-  
+
   G_OBJECT_CLASS (bjb_selection_toolbar_parent_class)->constructed (obj);
 
-  /* item(s) selected --> fade in */
+
+  priv->trash_bar = bjb_trash_bar_new (
+          bjb_window_base_get_controller (
+                BJB_WINDOW_BASE (
+                  bjb_main_view_get_window (self->priv->view))),
+          self->priv->view,
+          self->priv->selection);
+
+
+
   g_signal_connect (self->priv->selection,
                     "view-selection-changed", 
                     G_CALLBACK(bjb_selection_toolbar_selection_changed),
                     self);
 
+  g_signal_connect (priv->toolbar_tag,"clicked",
+                    G_CALLBACK (action_tag_selected_items), self);
+
   g_signal_connect_swapped (priv->toolbar_color,"clicked",
                     G_CALLBACK (hide_self), self);
 
   g_signal_connect (priv->toolbar_color,"color-set",
                     G_CALLBACK (action_color_selected_items), self);
 
-  g_signal_connect (priv->toolbar_tag,"clicked",
-                    G_CALLBACK (action_tag_selected_items), self);
+  g_signal_connect (priv->toolbar_share, "clicked",
+                    G_CALLBACK (action_share_item_callback), self);
 
   g_signal_connect (priv->toolbar_trash,"clicked",
                     G_CALLBACK (action_delete_selected_items), self);
